@@ -89,9 +89,14 @@ static int get_fontstretch (PangoStretch val)
 
 static double get_fontsize (double val) {return (double) val / (double) PANGO_SCALE;}
 
-static void on_compression_changed (GtkSpinButton *btn)
+static void on_compression_changed (GtkSpinButton *btn, Application *App)
 {
 	CompressionLevel = gtk_spin_button_get_value_as_int (btn);
+#ifdef HAVE_GO_CONF_SYNC
+	GOConfNode *node = go_conf_get_node (App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+	go_conf_set_int (node, "compression", CompressionLevel);
+	go_conf_free_node (node);
+#else
 	GConfClient *conf_client = gconf_client_get_default ();
 	GError *error = NULL;
 	gconf_client_set_int (conf_client, ROOTDIR"compression", CompressionLevel, &error);
@@ -100,11 +105,17 @@ static void on_compression_changed (GtkSpinButton *btn)
 		g_error_free (error);
 	}
 	g_object_unref (conf_client);
+#endif
 }
 
-static void on_tearable_mendeleiev_changed (GtkToggleButton *btn)
+static void on_tearable_mendeleiev_changed (GtkToggleButton *btn, Application *App)
 {
 	TearableMendeleiev = gtk_toggle_button_get_active (btn);
+#ifdef HAVE_GO_CONF_SYNC
+	GOConfNode *node = go_conf_get_node (App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+	go_conf_set_bool (node, "tearable-mendeleiev", TearableMendeleiev);
+	go_conf_free_node (node);
+#else
 	GConfClient *conf_client = gconf_client_get_default ();
 	GError *error = NULL;
 	gconf_client_set_bool (conf_client, ROOTDIR"tearable-mendeleiev", TearableMendeleiev, &error);
@@ -113,6 +124,7 @@ static void on_tearable_mendeleiev_changed (GtkToggleButton *btn)
 		g_error_free (error);
 	}
 	g_object_unref (conf_client);
+#endif
 }
 
 static void on_new_theme (PrefsDlg *dlg)
@@ -276,11 +288,11 @@ PrefsDlg::PrefsDlg (Application *pApp):
 	// compression level
 	GtkWidget *w = glade_xml_get_widget (xml, "compression");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), CompressionLevel);
-	g_signal_connect (G_OBJECT (w), "value-changed", G_CALLBACK (on_compression_changed), NULL);
+	g_signal_connect (G_OBJECT (w), "value-changed", G_CALLBACK (on_compression_changed), pApp);
 	// tearable table of the elements
 	w = glade_xml_get_widget (xml, "tearable-mendeleiev-btn");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TearableMendeleiev);
-	g_signal_connect (G_OBJECT (w), "toggled", G_CALLBACK (on_tearable_mendeleiev_changed), NULL);
+	g_signal_connect (G_OBJECT (w), "toggled", G_CALLBACK (on_tearable_mendeleiev_changed), pApp);
 	// retrieve theme widgets and set signals
 	m_BondLengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length-btn"));
 	g_signal_connect (G_OBJECT (m_BondLengthBtn), "value-changed", G_CALLBACK (on_bond_length_changed), this);
@@ -606,6 +618,11 @@ void PrefsDlg::OnBondLength (double length)
 		m_CurTheme->m_BondLength = length;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "bond-length", length);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"bond-length", length, &error);
@@ -614,6 +631,7 @@ void PrefsDlg::OnBondLength (double length)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -632,6 +650,11 @@ void PrefsDlg::OnBondAngle (double angle)
 		m_CurTheme->m_BondAngle = angle;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "bond-angle", angle);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"bond-angle", angle, &error);
@@ -640,6 +663,7 @@ void PrefsDlg::OnBondAngle (double angle)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -658,6 +682,11 @@ void PrefsDlg::OnBondWidth (double width)
 		m_CurTheme->m_BondWidth = width;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "bond-width", width);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"bond-width", width, &error);
@@ -666,6 +695,7 @@ void PrefsDlg::OnBondWidth (double width)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -684,6 +714,11 @@ void PrefsDlg::OnBondDist (double dist)
 		m_CurTheme->m_BondDist = dist;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "bond-dist", dist);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"bond-dist", dist, &error);
@@ -692,6 +727,7 @@ void PrefsDlg::OnBondDist (double dist)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -710,6 +746,11 @@ void PrefsDlg::OnStereoBondWidth (double width)
 		m_CurTheme->m_StereoBondWidth = width;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "stereo-width", width);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"stereo-width", width, &error);
@@ -718,6 +759,7 @@ void PrefsDlg::OnStereoBondWidth (double width)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -736,6 +778,11 @@ void PrefsDlg::OnHashWidth (double width)
 		m_CurTheme->m_HashWidth = width;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "hash-width", width);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"hash-width", width, &error);
@@ -744,6 +791,7 @@ void PrefsDlg::OnHashWidth (double width)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -762,6 +810,11 @@ void PrefsDlg::OnHashDist (double dist)
 		m_CurTheme->m_HashDist = dist;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "hash-dist", dist);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"hash-dist", dist, &error);
@@ -770,6 +823,7 @@ void PrefsDlg::OnHashDist (double dist)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -799,6 +853,11 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_string (node, "font-family", Name);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 				gconf_client_set_string (conf_client, ROOTDIR"font-family", Name, &error);
@@ -807,6 +866,7 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 					g_error_free (error);
 				}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -821,6 +881,11 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_int (node, "font-style", get_fontstyle (Style));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_int (conf_client, ROOTDIR"font-style", get_fontstyle (Style), &error);
@@ -829,6 +894,7 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -843,6 +909,11 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_int (node, "font-weight", get_fontweight (Weight));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_int (conf_client, ROOTDIR"font-weight", get_fontweight (Weight), &error);
@@ -851,6 +922,7 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -865,6 +937,11 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_int (node, "font-stretch", get_fontstretch (Stretch));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_int (conf_client, ROOTDIR"font-stretch", get_fontstretch (Stretch), &error);
@@ -873,6 +950,7 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -887,6 +965,11 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_int (node, "font-variant", get_fontvariant (Variant));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_int (conf_client, ROOTDIR"font-variant", get_fontvariant (Variant), &error);
@@ -895,6 +978,7 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -909,6 +993,11 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "font-size", get_fontsize (Size));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"font-size", get_fontsize (Size), &error);
@@ -917,6 +1006,7 @@ void PrefsDlg::OnFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -947,6 +1037,11 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_string (node, "text-font-family", Name);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_string (conf_client, ROOTDIR"text-font-family", Name, &error);
@@ -955,6 +1050,7 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -969,6 +1065,11 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_int (node, "text-font-style", get_fontstyle (Style));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_int (conf_client, ROOTDIR"text-font-style", get_fontstyle (Style), &error);
@@ -977,6 +1078,7 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -991,6 +1093,11 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_int (node, "text-font-weight", get_fontweight (Weight));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_int (conf_client, ROOTDIR"text-font-weight", get_fontweight (Weight), &error);
@@ -999,6 +1106,7 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1013,6 +1121,11 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_int (node, "text-font-stretch", get_fontstretch (Stretch));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_int (conf_client, ROOTDIR"text-font-stretch", get_fontstretch (Stretch), &error);
@@ -1021,6 +1134,7 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1035,6 +1149,11 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_int (node, "text-font-variant", get_fontvariant (Variant));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_int (conf_client, ROOTDIR"text-font-variant", get_fontvariant (Variant), &error);
@@ -1043,6 +1162,7 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1057,6 +1177,11 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 		changed = true;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "text-font-size", get_fontsize (Size));
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"text-font-size", get_fontsize (Size), &error);
@@ -1065,6 +1190,7 @@ void PrefsDlg::OnTextFont (GcpFontSel *fs)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1086,6 +1212,11 @@ void PrefsDlg::OnArrowLength (double length)
 		m_CurTheme->m_ArrowLength = length;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "arrow-length", length);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"arrow-length", length, &error);
@@ -1094,6 +1225,7 @@ void PrefsDlg::OnArrowLength (double length)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1112,6 +1244,11 @@ void PrefsDlg::OnArrowWidth (double width)
 		m_CurTheme->m_ArrowWidth = width;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "arrow-width", width);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"arrow-width", width, &error);
@@ -1120,6 +1257,7 @@ void PrefsDlg::OnArrowWidth (double width)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1138,6 +1276,11 @@ void PrefsDlg::OnArrowDist (double dist)
 		m_CurTheme->m_ArrowDist = dist;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "arrow-dist", dist);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"arrow-dist", dist, &error);
@@ -1146,6 +1289,7 @@ void PrefsDlg::OnArrowDist (double dist)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1164,6 +1308,11 @@ void PrefsDlg::OnArrowPadding (double padding)
 		m_CurTheme->m_ArrowPadding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "arrow-padding", padding);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"arrow-padding", padding, &error);
@@ -1172,6 +1321,7 @@ void PrefsDlg::OnArrowPadding (double padding)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1189,6 +1339,11 @@ void PrefsDlg::OnArrowHeadA (double headA)
 		m_CurTheme->m_ArrowHeadA = headA;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "arrow-headA", headA);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"arrow-headA", headA, &error);
@@ -1197,6 +1352,7 @@ void PrefsDlg::OnArrowHeadA (double headA)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1215,6 +1371,11 @@ void PrefsDlg::OnArrowHeadB (double headB)
 		m_CurTheme->m_ArrowHeadB = headB;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "arrow-headB", headB);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"arrow-headB", headB, &error);
@@ -1223,6 +1384,7 @@ void PrefsDlg::OnArrowHeadB (double headB)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1241,6 +1403,11 @@ void PrefsDlg::OnArrowHeadC (double headC)
 		m_CurTheme->m_ArrowHeadC = headC;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "arrow-headC", headC);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"arrow-headC", headC, &error);
@@ -1249,6 +1416,7 @@ void PrefsDlg::OnArrowHeadC (double headC)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1268,6 +1436,11 @@ void PrefsDlg::OnScale (double scale)
 		m_CurTheme->m_ZoomFactor = zoom;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "scale", scale);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"scale", scale, &error);
@@ -1276,6 +1449,7 @@ void PrefsDlg::OnScale (double scale)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1293,6 +1467,11 @@ void PrefsDlg::OnPadding (double padding)
 		m_CurTheme->m_Padding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "padding", padding);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"padding", padding, &error);
@@ -1301,6 +1480,7 @@ void PrefsDlg::OnPadding (double padding)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1318,6 +1498,11 @@ void PrefsDlg::OnObjectPadding (double padding)
 		m_CurTheme->m_ObjectPadding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "object-padding", padding);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"object-padding", padding, &error);
@@ -1326,6 +1511,7 @@ void PrefsDlg::OnObjectPadding (double padding)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1343,6 +1529,11 @@ void PrefsDlg::OnStoichPadding (double padding)
 		m_CurTheme->m_StoichiometryPadding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "stoichiometry-padding", padding);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"stoichiometry-padding", padding, &error);
@@ -1351,7 +1542,8 @@ void PrefsDlg::OnStoichPadding (double padding)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
-			break;
+#endif
+		break;
 		}
 		case LOCAL_THEME_TYPE:
 			m_CurTheme->modified = true;
@@ -1368,6 +1560,11 @@ void PrefsDlg::OnSignPadding (double padding)
 		m_CurTheme->m_SignPadding = padding;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "sign-padding", padding);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"sign-padding", padding, &error);
@@ -1376,6 +1573,7 @@ void PrefsDlg::OnSignPadding (double padding)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1393,6 +1591,11 @@ void PrefsDlg::OnChargeSize(double size)
 		m_CurTheme->m_ChargeSignSize = size;
 		switch (m_CurTheme->m_ThemeType) {
 		case DEFAULT_THEME_TYPE: {
+#ifdef HAVE_GO_CONF_SYNC
+			GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+			go_conf_set_double (node, "charge-sign-size", size);
+			go_conf_free_node (node);
+#else
 			GConfClient *conf_client = gconf_client_get_default ();
 			GError *error = NULL;
 			gconf_client_set_float (conf_client, ROOTDIR"charge-sign-size", size, &error);
@@ -1401,6 +1604,7 @@ void PrefsDlg::OnChargeSize(double size)
 				g_error_free (error);
 			}
 			g_object_unref (conf_client);
+#endif
 			break;
 		}
 		case LOCAL_THEME_TYPE:
@@ -1474,6 +1678,11 @@ bool PrefsDlg::CheckError ()
 void PrefsDlg::SetDefaultTheme (char const *name)
 {
 	TheThemeManager.SetDefaultTheme (name);
+#ifdef HAVE_GO_CONF_SYNC
+	GOConfNode *node = go_conf_get_node (m_App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+	go_conf_set_string (node, "default-theme", name);
+	go_conf_free_node (node);
+#else
 	GConfClient *conf_client = gconf_client_get_default ();
 	GError *error = NULL;
 	gconf_client_set_string (conf_client, ROOTDIR"default-theme", name, &error);
@@ -1482,6 +1691,7 @@ void PrefsDlg::SetDefaultTheme (char const *name)
 		g_error_free (error);
 	}
 	g_object_unref (conf_client);
+#endif
 }
 
 }	//	namespace gcp
